@@ -15,7 +15,7 @@
 import unittest
 
 import sys
-sys.path.append('..')
+sys.path.extend('..')
 import enum
 
 
@@ -32,11 +32,11 @@ class ValuesFixture(object):
         """ Set up the test fixtures """
 
         self.bad_keys = [ None, 0, 1, (), Mock_Enum(),
-            enum.EnumValue(Mock_Enum(), 'bogus', 0),
+            enum.EnumValue(Mock_Enum(), 0, 'bogus'),
         ]
 
         self.other_values = [ None, 0, 1, (), Mock_Enum(), "bogus",
-            enum.EnumValue(Mock_Enum(), 'bogus', 0),
+            enum.EnumValue(Mock_Enum(), 0, 'bogus'),
         ]
 
         self.planet_dict = dict(
@@ -74,19 +74,11 @@ class ValuesFixture(object):
         for enumtype, params in self.valid_values.items():
             values = {}
             for i, key in enumerate(params['keys']):
-                values[key] = enum.EnumValue(enumtype, key, i)
+                values[key] = enum.EnumValue(enumtype, i, key)
             params.update(dict(enumtype=enumtype, values=values))
 
 
-class ClassHierarchyTest(object):
-    """ Mix-in to provide testing for class inheritance """
-
-    def failUnlessInherited(self, instance, base):
-        """ Assert that the instance is inherited from the base """
-        if not base in instance.__class__.__bases__:
-            raise self.failureException, base
-
-class Test_EnumException(unittest.TestCase, ClassHierarchyTest):
+class Test_EnumException(unittest.TestCase):
     """ Test case for the Enum exception classes """
 
     def setUp(self):
@@ -166,6 +158,20 @@ class Test_EnumValue(unittest.TestCase, ValuesFixture):
 
         self.iterate_test(test_func)
 
+    def test_enumtype_equal(self):
+        """ EnumValue should export its enum type """
+        def test_func(enumtype, i, key, value):
+            self.failUnlessEqual(enumtype, value.enumtype)
+
+        self.iterate_test(test_func)
+
+    def test_key_equal(self):
+        """ EnumValue should export its string key """
+        def test_func(enumtype, i, key, value):
+            self.failUnlessEqual(key, value.key)
+
+        self.iterate_test(test_func)
+
     def test_str_key(self):
         """ String value for EnumValue should be its key string """
         def test_func(enumtype, i, key, value):
@@ -173,15 +179,22 @@ class Test_EnumValue(unittest.TestCase, ValuesFixture):
 
         self.iterate_test(test_func)
 
+    def test_index_equal(self):
+        """ EnumValue should export its sequence index """
+        def test_func(enumtype, i, key, value):
+            self.failUnlessEqual(i, value.index)
+
+        self.iterate_test(test_func)
+
     def test_repr(self):
         """ Representation of EnumValue should be meaningful """
         def test_func(enumtype, i, key, value):
             value_repr = repr(value)
             self.failUnless(value_repr.startswith('EnumValue('))
-            self.failUnless(value_repr.endswith(')'))
             self.failUnless(value_repr.count(repr(enumtype)))
-            self.failUnless(value_repr.count(repr(key)))
             self.failUnless(value_repr.count(repr(i)))
+            self.failUnless(value_repr.count(repr(key)))
+            self.failUnless(value_repr.endswith(')'))
 
     def test_hash_equal(self):
         """ Each EnumValue instance should have same hash as its value """
@@ -204,7 +217,7 @@ class Test_EnumValue(unittest.TestCase, ValuesFixture):
         """ An EnumValue should compare equal to its value """
         def test_func(enumtype, i, key, value):
             self.failUnlessEqual(value,
-                enum.EnumValue(enumtype, key, i)
+                enum.EnumValue(enumtype, i, key)
             )
 
         self.iterate_test(test_func)
@@ -225,7 +238,7 @@ class Test_EnumValue(unittest.TestCase, ValuesFixture):
                 for j, right_key in enumerate(params['keys']):
                     self.failUnlessEqual(cmp(i, j),
                         cmp(params['values'][left_key],
-                            enum.EnumValue(enumtype, right_key, j)
+                            enum.EnumValue(enumtype, j, right_key)
                         )
                     )
 
@@ -233,14 +246,14 @@ class Test_EnumValue(unittest.TestCase, ValuesFixture):
         """ An EnumValue should not allow comparison to other enums """
         def test_func(enumtype, i, key, value):
             self.failUnlessRaises(enum.EnumValueCompareError,
-                cmp, value, enum.EnumValue(self.SimpleEnum, key, i)
+                cmp, value, enum.EnumValue(self.SimpleEnum, i, key)
             )
 
         self.iterate_test(test_func)
 
     def test_cmp_non_enum(self):
         """ An EnumValue should not allow comparison to other types """
-        test_value = enum.EnumValue(self.SimpleEnum, 'test', 0)
+        test_value = enum.EnumValue(self.SimpleEnum, 0, 'test')
         for other in self.other_values:
             self.failUnlessRaises(enum.EnumValueCompareError,
                 cmp, test_value, other
